@@ -202,6 +202,11 @@ LOGGING = {
             'level': 'DEBUG',
             'propagate': True,
             'handlers': ['console'],
-        }
+        },
+        'amp': {
+            'level': 'DEBUG',
+            'propagate': True,
+            'handlers': ['console'],
+        },
     }
 }
