@@ -186,7 +186,7 @@ class ABlogIndexPage(AmpMixin, WagtailPageBakeryModel, GenericPage):
                     return RouteResult(self, kwargs={"tag": tag})
                 raise Http404
             else:
-                path_components[0] = path_components[0][:50]
+                path_components[0] = path_components[0]
         return super(ABlogIndexPage, self).route(request, path_components)
 
     @property
@@ -211,7 +211,7 @@ class ABlogIndexPage(AmpMixin, WagtailPageBakeryModel, GenericPage):
             blogs = paginator.page(paginator.num_pages)
         context = super(ABlogIndexPage, self).get_context(request)
         context['blogs'] = blogs
-        context['tags'] = Tag.objects.all()
+        context['tags'] = Tag.objects.filter(cms_blogpagetag_items__isnull=False).distinct()
         context['current_tag'] = tag
         return context
 
